@@ -13,7 +13,7 @@
 #' with the estimated nondecision distributions. If a traditional analysis was run the argument resND can
 #' be omitted.
 #'
-#' @return a list (S3 object of class 'DstarM') that contains:
+#' @return Returns a list of class \code{DstarM.fitObs} that contains:
 #'
 #' \item{obsNorm}{A matrix containing normalized densities of each condition response pair.}
 #' \item{obs}{A matrix containing unnormalized densities of each condition response pair.}
@@ -57,16 +57,17 @@
 #'}
 
 #' @export
-estObserved = function(resDecision, resND = NULL, data = NULL, interpolateND = FALSE, tt = NULL) {
-  if (!is.DstarM(resDecision)) {
-    stop('Argument resDecision must be of class "DstarM".', call. = FALSE)
+estObserved <- function(resDecision, resND = NULL, data = NULL, interpolateND = FALSE,
+  tt = NULL) {
+  if (!is.DstarM.fitD(resDecision)) {
+    stop("Argument resDecision must be of class \"DstarM\".", call. = FALSE)
   }
 
-  fit = list()
+  fit <- list()
 
   if (resDecision$DstarM) {
-    if (!is.DstarM(resND)) {
-      stop('Argument resND must be of class "DstarM".', call. = FALSE)
+    if (!is.DstarM.fitND(resND)) {
+      stop("Argument resND must be of class \"DstarM\".", call. = FALSE)
     }
 
     if (!is.null(tt)) {
@@ -74,115 +75,116 @@ estObserved = function(resDecision, resND = NULL, data = NULL, interpolateND = F
     }
 
     # get time grids
-    ttDec = resDecision$tt
-    tt = resND$tt # everything will be conformed to nondecision grid
+    ttDec <- resDecision$tt
+    tt <- resND$tt  # everything will be conformed to nondecision grid
 
-    reCalcND = FALSE
+    reCalcND <- FALSE
 
-    # get model densities --if they don't match recalculate model densities at tt
+    # get model densities --if they don't match recalculate model densities
+    # at tt
     if (length(ttDec) != length(tt) || !isTRUE(all.equal(ttDec, tt))) {
-      if (interpolateND){ # interpolate nondecision model
+      if (interpolateND) {
+        # interpolate nondecision model
 
         message("Decision model and Nondecision model estimated at different time grids. Interpolating Nondecision model to time grid of decision model.")
-        reCalcND = TRUE
-        dd = resDecision$modelDist
+        reCalcND <- TRUE
+        dd <- resDecision$modelDist
 
-      } else { # recalculate decision model at new grid
+      } else {
+        # recalculate decision model at new grid
 
         message("Decision model and Nondecision model estimated at different time grids. Recalculating decision model with time grid of nondecision model.")
-        dd = getPdfs(resDecision = resDecision, tt = tt, DstarM = TRUE)
+        dd <- getPdfs(resDecision = resDecision, tt = tt, DstarM = TRUE)
 
       }
-    } else { # get model pdfs from input
+    } else {
+      # get model pdfs from input
 
-      dd = resDecision$modelDist
+      dd <- resDecision$modelDist
 
     }
 
-    nd = resND$r.hat
-    splits = resDecision$splits
+    nd <- resND$r.hat
+    splits <- resDecision$splits
     if (reCalcND) {
-      nd2 = matrix(nrow = length(ttDec), ncol = ncol(nd))
+      nd2 <- matrix(nrow = length(ttDec), ncol = ncol(nd))
       for (i in 1:ncol(nd)) {
-        nd2[, i] = stats::approx(x = tt, y = nd[, i], xout = ttDec)$y
+        nd2[, i] <- stats::approx(x = tt, y = nd[, i], xout = ttDec)$y
       }
-      nd = nd2
+      nd <- nd2
     }
-    nd = nd[nrow(nd):1, , drop = FALSE] # reverse for convolution]
+    nd <- nd[nrow(nd):1, , drop = FALSE]  # reverse for convolution]
 
     # error handling
     if (dim(nd)[2L] != length(unique(splits))) {
-      sign = ifelse(dim(nd)[2L] < length(unique(splits)),
-                    'Less', 'More')
-      stop(sprintf('%s nondecision distributions (%d) than were assumed while estimating the decision model (%d).',
-                   sign, as.integer(dim(nd)[2L]), as.integer(length(unique(splits)))), call. = FALSE)
+      sign <- ifelse(dim(nd)[2L] < length(unique(splits)), "Less",
+        "More")
+      stop(sprintf("%s nondecision distributions (%d) than were assumed while estimating the decision model (%d).",
+        sign, as.integer(dim(nd)[2L]), as.integer(length(unique(splits)))),
+        call. = FALSE)
     }
 
-    # assign indices for nds to match dds
-    # this converts splits from whatever it is to 1, 2, ...
-    # and then repeats each element twice since split is per
-    # condition and not per condition-response pair.
-    idxND = rep(apply(as.matrix(c(splits)), 1, function(x, eq) which(x == eq), eq = unique(c(splits))), each = 2)
+    # assign indices for nds to match dds this converts splits from whatever
+    # it is to 1, 2, ...  and then repeats each element twice since split is
+    # per condition and not per condition-response pair.
+    idxND <- rep(apply(as.matrix(c(splits)), 1, function(x, eq) which(x ==
+      eq), eq = unique(c(splits))), each = 2)
 
-    by = diff(tt)[1] # for normalization
-    idxC = seq_along(tt) # keep only this part of convolutions
-    obs = matrix(NA, length(tt), dim(dd)[2L])
+    by <- diff(tt)[1]  # for normalization
+    idxC <- seq_along(tt)  # keep only this part of convolutions
+    obs <- matrix(NA, length(tt), dim(dd)[2L])
     for (i in 1:dim(dd)[2L]) {
-      obs[, i] = customConvolveO(dd[, i], by*nd[, idxND[i]])[idxC]
+      obs[, i] <- customConvolveO(dd[, i], by * nd[, idxND[i]])[idxC]
     }
     # non approximated convolutions after all
-    obs[obs <= 0] = 0 #.Machine$double.xmin
+    obs[obs <= 0] <- 0  #.Machine$double.xmin
 
-    fit$ND = sapply(resND$GlobalOptimizer, function(x) x$optim$bestval)
-    fit$Decision = resDecision$GlobalOptimizer$optim$bestval
-  } else { # traditional analysis
+    fit$ND <- sapply(resND$GlobalOptimizer, function(x) x$optim$bestval)
+    fit$Decision <- resDecision$GlobalOptimizer$optim$bestval
+  } else {
+    # traditional analysis
     if (is.null(tt)) {
 
-      tt = resDecision$tt
-      obs = resDecision$modelDist
+      tt <- resDecision$tt
+      obs <- resDecision$modelDist
 
     } else {
 
-      obs = getPdfs(resDecision, tt, DstarM = resDecision$DstarM)
+      obs <- getPdfs(resDecision, tt, DstarM = resDecision$DstarM)
 
     }
   }
   if (!is.null(data)) {
 
-    fit$chisq = chisqFit(resObserved = obs, data = data, tt = tt)
+    fit$chisq <- chisqFit(resObserved = obs, data = data, tt = tt)
 
   } else if (!resDecision$DstarM) {
 
-    fit = resDecision$GlobalOptimizer$optim$bestval
+    fit <- resDecision$GlobalOptimizer$optim$bestval
 
   }
 
-  cor = apply(obs, 2, simpson, x = tt)
-  obsNorm = obs %*% (diag(dim(obs)[2L]) / cor)
-  colnames(obsNorm) = colnames(obs)
-  npar = length(resDecision$Bestvals) - ifelse(!is.null(resDecision$fixed$fixedMat), dim(resDecision$fixed$fixedMat)[2L], 0)
+  cor <- apply(obs, 2, simpson, x = tt)
+  obsNorm <- obs %*% (diag(dim(obs)[2L])/cor)
+  colnames(obsNorm) <- colnames(obs)
+  npar <- length(resDecision$Bestvals) - ifelse(!is.null(resDecision$fixed$fixedMat),
+    dim(resDecision$fixed$fixedMat)[2L], 0)
 
   # observe any not observed conditions, makes later plotting easier
-  obsIdx = which(colSums(resDecision$g.hat) == 0)
-  res = list(obsNorm = obsNorm, obs = obs, tt = tt, fit = fit, npar = npar,
-             obsIdx = obsIdx, ncondition = resDecision$ncondition,
-             resDecision = resDecision, resND = resND,
-             interpolateND = interpolateND)
-  class(res) = "DstarM"
+  obsIdx <- which(colSums(resDecision$g.hat) == 0)
+  res <- list(obsNorm = obsNorm, obs = obs, tt = tt, fit = fit, npar = npar,
+    obsIdx = obsIdx, ncondition = resDecision$ncondition, resDecision = resDecision,
+    resND = resND, interpolateND = interpolateND)
+  class(res) <- "DstarM.fitObs"
   return(res)
 }
 
 
-# TEST
-# root = 'C:/Users/donvd/_Laptop/ResMas/Internship/DstarM/massSimulation/Simulation/'
-# select = read.table(paste0(root, 'BestSetsExp4a.txt'))
-#
-# pp = 1
-# idx = select[1, ]
-# load(paste0(root, 'ResultsExp4a/', 'pp_', pp, '_rep_', idx, '.Rdata'))
-# resDecision = res
-# load(paste0(root, 'ResultsExp5/', 'ND', pp, '.Rdata'))
-#
-# obs = estObserved(resDecision, resND)
-# plotObserved(resObserved = obs, data = )
-# matplot(obs, type = 'l', lty = 1)
+# TEST root =
+# 'C:/Users/donvd/_Laptop/ResMas/Internship/DstarM/massSimulation/Simulation/'
+# select = read.table(paste0(root, 'BestSetsExp4a.txt')) pp = 1 idx =
+# select[1, ] load(paste0(root, 'ResultsExp4a/', 'pp_', pp, '_rep_', idx,
+# '.Rdata')) resDecision = res load(paste0(root, 'ResultsExp5/', 'ND',
+# pp, '.Rdata')) obs = estObserved(resDecision, resND)
+# plotObserved(resObserved = obs, data = ) matplot(obs, type = 'l', lty =
+# 1)
